@@ -746,7 +746,7 @@ class VectorStoreWrapper(BaseToolApiWrapper):
 
         try:
             dispatch_custom_event(
-                name="thinking_step_update",
+                name="thinking_step",
                 data={
                     "message": message,
                     "tool_name": tool_name,
